/**
 * Copyright (C) 2003-2007 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */


package com.funambol.framework.core;

import java.util.*;

/**
 * This class corresponds to the &lt;CTCap&gt; tag in the SyncML devinf DTD
 *
 * 
 *
 *  @version $Id: CTCap.java,v 1.3 2007/01/11 19:30:39 nichele Exp $
 */
public final class CTCap
implements java.io.Serializable {

    // ------------------------------------------------------------ Private data
    private ArrayList ctTypeSupported = new ArrayList();

    // ------------------------------------------------------------ Constructors
    /** For serialization purposes */
    protected CTCap() {}

    /**
     * Creates a new CTCap object with the given array of information
     *
     * @param ctTypeSupported the array of information on content type
     *                        capabilities - NOT NULL
     *
     */
    public CTCap(final CTTypeSupported[] ctTypeSupported) {
        setCTTypeSupported(ctTypeSupported);
    }

    // ---------------------------------------------------------- Public methods

    /**
     * Get an array of content type information objects
     *
     * @return an array of content type information objects
     */
    public ArrayList getCTTypeSupported() {
        return this.ctTypeSupported;
    }

    /**
     * Sets an array of content type information objects
     *
     * @param ctTypeSupported an array of content type information objects
     */
    public void setCTTypeSupported(CTTypeSupported[] ctTypeSupported) {

        if (ctTypeSupported == null || ctTypeSupported.length == 0) {
            throw new IllegalArgumentException("ctTypeSupported cannot be null");
        }
        this.ctTypeSupported.clear();
        this.ctTypeSupported.addAll(Arrays.asList(ctTypeSupported));
    }
}
