/**
 * Copyright (C) 2003-2007 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */
package com.funambol.framework.core;

import com.funambol.framework.core.dm.ddf.MgmtTree;

/**
 * Corresponds to the &lt;Data&gt; tag in the SyncML represent DTD when delivering
 * an Anchor
 *
 * @version $Id: ComplexData.java,v 1.4 2007/01/11 19:30:39 nichele Exp $
 */
public final class ComplexData
extends Data
implements java.io.Serializable {

    // ------------------------------------------------------------ Private data
    private Anchor anchor;
    private DevInf devInf;

    private MgmtTree mgmtTree;

    // ------------------------------------------------------------ Constructors
    /** For serialization purposes */
    public ComplexData() {}

    /**
     * Creates a Data object from the given anchors string.
     *
     * @param data the anchor
     *
     */
    public ComplexData(String data) {
        super(data);
    }


    // ---------------------------------------------------------- Public methods

    /**
     * Gets the Anchor object property
     *
     * @return anchor the Anchor object
     */
    public Anchor getAnchor() {
        return anchor;
    }

    /**
     * Sets the Anchor object property
     *
     * @param anchor the Anchor object
     */
    public void setAnchor(Anchor anchor) {
        if (null == anchor) {
            throw new IllegalArgumentException("anchor cannot be null");
        }
        this.anchor = anchor;
    }

    /**
     * Gets the DevInf object property
     *
     * @return devInf the DevInf object property
     */
    public DevInf getDevInf() {
        return devInf;
    }

    /**
     * Sets the DevInf object property
     *
     * @param devInf the DevInf object property
     *
     */
    public void setDevInf(DevInf devInf) {
        if (null == devInf) {
            throw new IllegalArgumentException("devInf cannot be null");
        }
        this.devInf = devInf;
    }

    public MgmtTree getMgmtTree() {
        return mgmtTree;
    }
    
    public void setMgmtTree(MgmtTree mgmtTree) {
        if (null == mgmtTree) {
            throw new IllegalArgumentException("mgmtTree cannot be null");
        }
        this.mgmtTree = mgmtTree;
    }

}
