/**
 * Copyright (C) 2003-2007 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */


package com.funambol.framework.core;

import java.util.*;

/**
 * This class represents the content type parameter such as paramName, valEnum,
 * displayName or data type
 *
 *
 *
 * @version $Id: ContentTypeParameter.java,v 1.3 2007/01/11 19:30:39 nichele Exp $
 */
public final class ContentTypeParameter
implements java.io.Serializable {

    // ------------------------------------------------------------ Private data
    private String paramName;
    private ArrayList valEnum = new ArrayList();
    private String displayName;
    private String dataType;
    private int size;

    // ------------------------------------------------------------ Constructors
    /** For serialization purposes */
    private ContentTypeParameter() {}

    /**
     * Creates a new ContentTypeParameter object with the given name, value and
     * display name
     *
     * @param paramName corresponds to &lt;ParamName&gt; element in the SyncML
     *                  specification - NOT NULL
     * @param valEnum   corresponds to &lt;ValEnum&gt; element in the SyncML
     *                  specification
     * @param displayName corresponds to &lt;DisplayName&gt; element in the SyncML
     *                  specification
     *
     */
    public ContentTypeParameter(final String paramName,
                                final String[] valEnum,
                                final String displayName) {
        setParamName(paramName);
        setValEnum(valEnum);

        this.displayName = displayName;
    }

    /**
     * Creates a new ContentTypeParameter object with the given name, data type,
     * size, display name
     *
     * @param paramName corresponds to &lt;ParamName&gt; element in the SyncML
     *                  specification - NOT NULL
     * @param dataType  corresponds to &lt;DataType&gt; element in the SyncML
     *                  specification
     * @param size      corresponds to &lt;Size&gt; element in the SyncML
     *                  specification
     * @param displayName corresponds to &lt;DisplayName&gt; element in the SyncML
     *                  specification
     *
     */
    public ContentTypeParameter(final String paramName,
                                final String dataType,
                                final int size,
                                final String displayName) {
        setParamName(paramName);

        this.dataType    = dataType;
        this.size        = size;
        this.displayName = displayName;
    }

    // ---------------------------------------------------------- Public methods

    /**
     * Gets the parameter name propeties
     *
     * @return the parameter name propeties
     */
    public String getParamName() {
        return paramName;
    }

    /**
     * Sets the param name property
     *
     * @param paramName the param name property
     */
    public void setParamName(String paramName) {
        if (paramName == null){
            throw new IllegalArgumentException("paramName cannot be null");
        }
        this.paramName = paramName;
    }

    /**
     * Gets the array of value for parameter
     *
     * @return the array of value for parameter
     */
    public ArrayList getValEnum() {
        return this.valEnum;
    }

    /**
     * Sets the array of enumerated value property
     *
     * @param valEnum the array of enumerated value property
     */
    public void setValEnum(String[] valEnum) {
        if (valEnum != null) {
            this.valEnum.clear();
            this.valEnum.addAll(Arrays.asList(valEnum));
        } else {
            this.valEnum = null;
        }
    }

    /**
     * Gets the display name propeties
     *
     * @return the display name propeties
     */
    public String getDisplayName() {
        return displayName;
    }

    /**
     * Sets the display name of a given content type parameter
     *
     * @param displayName the display name of a given content type parameter
     *
     */
    public void setDisplayName(String displayName) {
        this.displayName = displayName;
    }

    /**
     * Gets the data type propeties
     *
     * @return the data type propeties
     */
    public String getDataType() {
        return dataType;
    }

    /**
     * Sets the data type of a given content type parameter
     *
     * @param dataType the data type of a given content type parameter
     *
     */
    public void setDataType(String dataType) {
        this.dataType = dataType;
    }

    /**
     * Gets the size propeties
     *
     * @return the size propeties
     */
    public int getSize() {
        return size;
    }

    /**
     * Sets the size of a given content type parameter
     *
     * @param size the size of a given content type parameter
     *
     */
    public void setSize(int size) {
        this.size = size;
    }
}
