/**
 * Copyright (C) 2003-2007 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */


package com.funambol.framework.core;

/**
 * Corresponds to the &lt;Copy&gt; tag in the SyncML represent DTD
 *
 *
 *
 * @version $Id: Copy.java,v 1.3 2007/01/11 19:30:39 nichele Exp $
 */
public final class Copy
extends ModificationCommand
implements java.io.Serializable {

    // --------------------------------------------------------------- Constants
    public static String COMMAND_NAME = "Copy";

    // ------------------------------------------------------------ Constructors

    /** For serialization purposes */
    protected Copy() {}

    /**
     * Creates a new Copy object with the given command identifier, noResponse,
     * credential, meta and array of item
     *
     * @param cmdID the command identifier - NOT NULL
     * @param noResp true if no response is required
     * @param cred the authentication credential
     * @param meta the meta data
     * @param items the array of item - NOT NULL
     *
     */
    public Copy(final CmdID cmdID,
                final boolean noResp,
                final Cred cred,
                final Meta meta,
                final Item[] items) {
        super(cmdID, meta, items);

        this.noResp  = (noResp) ? new Boolean(noResp) : null;
        setCred(cred);
    }

   // ----------------------------------------------------------- Public methods

    /**
     * Gets the command name property
     *
     * @return the command name property
     */
    public String getName() {
        return Copy.COMMAND_NAME;
    }
}
