/**
 * Copyright (C) 2003-2007 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */
package com.funambol.framework.core;

/**
 * Corresponds to the &lt;Exec&gt; tag in the SyncML represent DTD
 *
 * @version $Id: Exec.java,v 1.4 2007/01/11 19:30:39 nichele Exp $
 */
public final class Exec
extends ModificationCommand
implements java.io.Serializable {

    // --------------------------------------------------------------- Constants
    public static String COMMAND_NAME = "Exec";

    // -------------------------------------------------------------- Properties
    private String correlator;

    public String getCorrelator() {
        return correlator;
    }

    public void setCorrelator(String newCorrelator) {
        this.correlator = newCorrelator;
    }

    // ------------------------------------------------------------ Constructors
    /** For serialization purposes */
    protected Exec() {}

    /**
     * Creates a new Exec object with the given command identifier,
     * noResponse, credential and item
     *
     * @param cmdID the command identifier - NOT NULL
     * @param noResp true if no response is required
     * @param cred the authentication credential
     * @param item the item - NOT NULL
     *
     */
    public Exec(final CmdID cmdID,
                final boolean noResp,
                final Cred cred,
                final String correlator,
                final Item item) {
        super(cmdID, new Item[] { item });

        this.noResp  = (noResp) ? new Boolean(noResp) : null;
        setCred(cred);
        this.correlator = correlator;
    }

    // ---------------------------------------------------------- Public methods
    /**
     * Gets the command name property
     *
     * @return the command name property
     */
    public String getName() {
        return Exec.COMMAND_NAME;
    }

    /**
     * Gets an Item object
     *
     * @return an Item object
     */
    public Item getItem() {
        return (Item)items.get(0);
    }
}
