/**
 * Copyright (C) 2003-2007 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */


package com.funambol.framework.core;

/**
 * This class represents the &lt;MapItem&gt; tag as defined by the SyncML r
 * epresentation specifications.
 *
 *
 *
 * @version $Id: MapItem.java,v 1.4 2007/01/11 19:30:39 nichele Exp $
 *
 */
public final class MapItem
implements java.io.Serializable {

    // ------------------------------------------------------------ Private data

    private Target target;
    private Source source;

    // ------------------------------------------------------------ Constructors

    /**
     * This is for serialization purposes
     */
    protected MapItem() {}

    /**
     * Creates a MapItem object from its target and source.
     *
     *  @param target the mapping target - NOT NULL
     *  @param source the mapping source - NOT NULL
     *
     *  @throws IllegalArgumentException if any parameter is null
     *
     */
    public MapItem(final Target target, final Source source) {
        setTarget(target);
        setSource(source);
    }

    // ---------------------------------------------------------- Public methods

    /**
     * Returns the MapItem's target
     *
     * @return Tthe MapItem's target
     *
     */
    public Target getTarget() {
        return target;
    }

    /**
     * Sets the MapItem's target
     *
     * @param target he MapItem's target - NOT NULL
     *
     * @throws IllegalArgumentException if target is null
     */
    public void setTarget(Target target) {
        if (target == null) {
            throw new IllegalArgumentException("target cannot be null");
        }
        this.target = target;
    }

    /**
     * Returns the MapItem's source
     *
     * @return Tthe MapItem's source
     *
     */
    public Source getSource() {
        return source;
    }

    /**
     * Sets the MapItem's source
     *
     * @param source he MapItem's source - NOT NULL
     *
     * @throws IllegalArgumentException if source is null
     */
    public void setSource(Source source) {
        if (source == null) {
            throw new IllegalArgumentException("source cannot be null");
        }
        this.source = source;
    }
}
