/**
 * Copyright (C) 2003-2007 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */


package com.funambol.framework.core;

import java.util.*;


/**
 * This class represents the synchronization capabilities of a datastore and
 * corresponds to the &lt;SyncCap&gt; tag in the SyncML devinf DTD
 *
 *  @see DataStore
 * 
 *
 *  @version $Id: SyncCap.java,v 1.3 2007/01/11 19:30:39 nichele Exp $
 */
public final class SyncCap
implements java.io.Serializable {

    // --------------------------------------------------------------- Constants
    private ArrayList syncTypes = new ArrayList();

    // ------------------------------------------------------------ Constructors

    /** For serialization purposes */
    protected SyncCap(){}

    /**
     * Creates a new SyncCap object that specifies the synchronization
     * capabilities of the given datastore
     *
     * @param syncTypes an array of type of the supported
     *                  synchronization - NOT NULL
     *
     */
    public SyncCap(final SyncType[] syncTypes) {
        setSyncType(syncTypes);
    }

    // ---------------------------------------------------------- Public methods

    /**
     *
     * @return The return value is guaranteed to be non-null.
     *      Also, the array's elements are guaranteed to
     *      be non-null.
     *
     */
    public ArrayList getSyncType() {
        return syncTypes;
    }

    public void setSyncType(SyncType[] syncTypes) {
        if (syncTypes == null || syncTypes.length == 0) {
            throw new IllegalArgumentException(
                                           "syncTypes cannot be null or empty");
        }
        this.syncTypes.clear();
        this.syncTypes.addAll(Arrays.asList(syncTypes));
    }
}
