/**
 * Copyright (C) 2003-2007 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */


package com.funambol.framework.core;


/**
 * This class corresponds to &lt;SyncType&gt; tag in SyncML devinfo DTD
 *
 * 
 *
 *  @version $Id: SyncType.java,v 1.3 2007/01/11 19:30:39 nichele Exp $
 */
public final class SyncType
implements java.io.Serializable {
    // --------------------------------------------------------------- Constants

    public static final SyncType TWO_WAY             = new SyncType(1);
    public static final SyncType SLOW                = new SyncType(2);
    public static final SyncType ONE_WAY_FROM_CLIENT = new SyncType(3);
    public static final SyncType REFRESH_FROM_CLIENT = new SyncType(4);
    public static final SyncType ONE_WAY_FROM_SERVER = new SyncType(5);
    public static final SyncType REFRESH_FROM_SERVER = new SyncType(6);
    public static final SyncType SERVER_ALERTED      = new SyncType(7);

    public static final SyncType[] ALL_SYNC_TYPES = new SyncType[] {
        TWO_WAY, SLOW, ONE_WAY_FROM_CLIENT, REFRESH_FROM_CLIENT,
        ONE_WAY_FROM_SERVER, REFRESH_FROM_SERVER, SERVER_ALERTED
    };

    // ------------------------------------------------------------ Private data
    private int syncType;

    // ------------------------------------------------------------ Constructors

    /** For serialization purposes */
    protected SyncType() {}

    /**
     * Creates a new SyncType object with syncType value
     *
     * @param syncType the value of SyncType - NOT NULL
     *
     */
    public SyncType(final int syncType) {
        setType(syncType);
    }

    // ---------------------------------------------------------- Public methods

    /**
     * Gets the synchronization type
     *
     * @return syncType the synchronization type
     */
    public int getType() {
        return syncType;
    }

    /**
     * Sets the synchronization type
     *
     * @param syncType the synchronization type
     */
    public void setType(int syncType) {
        this.syncType = syncType;
    }

    /**
     * Gets the instance of synchronization type
     *
     * @return syncType the synchronization type
     */
    public static final SyncType getInstance(final int syncType) {
        if ((syncType < 0) || (syncType >= ALL_SYNC_TYPES.length)) {
            throw new IllegalArgumentException("unknown syncType: " + syncType);
        }
        return ALL_SYNC_TYPES[syncType-1];
    }
}
