/**
 * Copyright (C) 2003-2007 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */

package com.funambol.framework.core.dm.bootstrap;

import java.util.Hashtable;
import java.util.Map;


/**
 * Corresponds to the &lt;PX&gt; interior node in the management tree
 *
 * @version $Id: PX.java,v 1.2 2007/01/11 19:30:39 nichele Exp $
 */
public class PX {

    // --------------------------------------------------------------- Constants

    public static final String PX_PORT_NBR  = "/PortNbr";
    public static final String PX_ADDR_TYPE = "/AddrType";
    public static final String PX_ADDR      = "/Addr";
    public static final String PX_AUTH      = "/Auth";

    // ------------------------------------------------------------ Private data
    private String portNbr;
    private String address;
    private String addressType;

    // contains all the pairs id/secret for each authentication methods
    private Map auths;

    // ------------------------------------------------------------ Constructors
    /** For serialization purposes */
    public PX() {
        this.auths = new Hashtable();
    }

    /**
     * Creates a new ConPX object with the given parameters
     * @param portNbr the port number to use
     * @param address the server address
     * @param addressType the type of the server address
     *
     */
    public PX(final String portNbr,
              final String address,
              final String addressType) {
        this();
        this.portNbr     = portNbr;
        this.address     = address;
        this.addressType = addressType;

    }

    // ---------------------------------------------------------- Public methods

    /**
     * Gets the portNbr
     *
     * @return  the portNbr
     */
    public String getPortNbr() {
        return portNbr;
    }

    /**
     * Sets the portNbr
     *
     * @param  portNbr the portNbr
     */
    public void setPortNbr(String portNbr) {
        this.portNbr = portNbr;
    }

    /**
     * Gets the address
     *
     * @return  the address
     */
    public String getAddress() {
        return address;
    }

    /**
     * Sets the address
     *
     * @param  address the address
     */
    public void setAddress(String address) {
        this.address = address;
    }

    /**
     * Gets the addressType
     *
     * @return  the addressType
     */
    public String getAddressType() {
        return addressType;
    }

    /**
     * Sets the addressType
     *
     * @param  addressType the addressType
     */
    public void setAddressType(String addressType) {
        this.addressType = addressType;
    }

    /**
     * Gets the <code>ConAuth</code> with the given name
     *
     * @return  the auth with the given name
     */
    public Auth getAuth(String authenticationName) {
        return (Auth)auths.get(authenticationName);
    }

    /*
     * Gets the authentications available
     *
     * @return  the authentications available
     */
    public Map getAuths() {
        return auths;
    }

    /*
     * Sets the auth
     *
     * @param  the auth
     */
    public void setAuths(Map auths) {
        this.auths = auths;
    }


    /**
     * Adds the auth
     *
     * @param  auth the auth to add
     * @param  authenticationName the authentication name
     */
    public void addAuth(Auth auth, String authenticationName) {
        auths.put(authenticationName, auth);
    }

}
