/**
 * Copyright (C) 2003-2007 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */

package com.funambol.framework.core.dm.bootstrap;

import java.io.Serializable;


/**
 * Corresponds to the &lt;parm&gt; tag in a Wap provisioning doc.
 *
 * @version $Id: Parm.java,v 1.2 2007/01/11 19:30:39 nichele Exp $
 */
public final class Parm implements Serializable {

    private static final long serialVersionUID = 6158602889561087131L;

    // -------------------------------------------------------------- Properties

    private String name;
    private String value;

    // ------------------------------------------------------------ Constructors
    public Parm() {
    }

    public Parm(String name, String value) {
        this.name  = name;
        setValue(value);
    }


    /**
     * Gets the name
     * @return the name of this parm
     */
    public String getName() {
        return name;
    }

    /**
     * Sets the name of this parm
     * @param name the name to sets
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * Gets the value
     * @return the value of this parm.
     */
    public String getValue() {
        return value;
    }

    /**
     * Sets the value of this parm
     * @param value the value to sets
     */
    public void setValue(String value) {
        this.value = ( (value == null) ? "" : value );
    }

    /**
     * Two Parm are equals if and only if:
     * <ul>
     *   <li>o is an instance of Parm and the name
     *  is the same</li>
     * </ul>
     *
     * @param o the reference object with which to compare.
     *
     * @return true if this object is the same as the obj argument; false otherwise.
     */
    public boolean equals(Object o) {
        if ((o == null) || !(o instanceof Parm)) {
            return false;
        }

        return (getName().equals(((Parm)o).getName()));
    }

    /**
     * Return the hashcode
     * @return int
     */
    public int hashCode() {
        return getName().hashCode();
    }
}
