/**
 * Copyright (C) 2003-2007 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */

package com.funambol.framework.core.dm.bootstrap;

import java.io.ByteArrayOutputStream;
import java.io.Serializable;

import java.util.ArrayList;
import java.util.List;

import org.jibx.runtime.BindingDirectory;
import org.jibx.runtime.IBindingFactory;
import org.jibx.runtime.IMarshallingContext;
import org.jibx.runtime.JiBXException;


/**
 * Corresponds to the &lt;wap-provisioningdoc&gt; tag in a Wap provisioning doc.
 *
 *
 *
 * @version $Id: WapProvisioningDoc.java,v 1.2 2007/01/11 19:30:39 nichele Exp $
 *
 */
public final class WapProvisioningDoc implements Serializable {

    private static final long serialVersionUID = 994146838047570571L;

    // -------------------------------------------------------------- Properties
    private ArrayList characteristics = null;

    private String version = null;

    // ------------------------------------------------------------ Constructors

    /**
     * Creates a new WapProvisioningDoc
     */
    public WapProvisioningDoc() {
        characteristics = new ArrayList();
    }


    /**
     * Creates a new WapProvisioningDoc with the given versione
     * @param version the version of this WapProvisioningDoc
     */
    public WapProvisioningDoc(String version) {
        this.version = version;
        characteristics = new ArrayList();
    }


    /**
      * Gets the version of this WapProvisioningDoc
      * @return the version of this WapProvisioningDoc
      */
     public String getVersion() {
         return version;
     }

     /**
      * Sets the version of this WapProvisioningDoc
      * @param version the version to set
      */
     public void setVersion(String version) {
         this.version = version;
     }

    /**
     * Adds new <code>Characteristic</code> to this WapProvisioningDoc
     *
     * @param characteristicToAdd the characteristic to add
     */
    public void addCharacteristic(Characteristic characteristicToAdd) {
        characteristics.add(characteristicToAdd);
    }

    /**
     * Adds a list of<code>Characteristic</code> to this WapProvisioningDoc
     *
     * @param characteristicsToAdd the characteristics to add
     */
    public void addCharacteristicList(List characteristicsToAdd) {
            characteristics.addAll(characteristicsToAdd);
    }

    /**
     * Returns the characteristcs list
     *
     */
    public ArrayList getCharacteristics() {
        return characteristics;
    }

    /**
     * Returns a xml representation of this WapProvisioningDoc
     * @return String
     */
    public String toXml() throws JiBXException {
        ByteArrayOutputStream bout = new ByteArrayOutputStream();

        IBindingFactory f = BindingDirectory.getFactory(WapProvisioningDoc.class);
        IMarshallingContext c = f.createMarshallingContext();
        c.setIndent(0);
        c.marshalDocument(this, "UTF-8", null, bout);

        String inputXml = new String(bout.toByteArray());

        return inputXml;

    }

}
