/**
 * Copyright (C) 2003-2007 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */

package com.funambol.framework.engine;

import com.funambol.framework.engine.source.SyncSource;
import com.funambol.framework.engine.SyncOperation;


/**
 * This class represents the status of the execution of a <i>SyncOperation</i>.
 * A reference to the related operation is stored in <i>operation</i>.
 * Subclasses of <i>SyncOperationStatus</i> represent particular status such as
 * OK or Error.
 *
 * @see com.funambol.framework.engine.SyncOperation
 *
 *
 */
public interface SyncOperationStatus {

    /**
     * Getter for operation this status relates to
     *
     * @return the operation this status relates to.
     *
     */
    public SyncOperation getOperation();

    /**
     * The <i>SyncSource</i> the operation was applied to
     *
     * @return the <i>SyncSource</i> the operation was applied to
     */
    public SyncSource getSyncSource();

    /** The operation status code
     * @return the operation status code
     */
    public int getStatusCode();
}
