/**
 * Copyright (C) 2003-2007 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */

package com.funambol.framework.engine.dm;

import java.util.Map;
import java.util.HashMap;

/**
 * This class represents the result of a single management operation.<br>
 * Note that differently by the Results comand, which can hold multiple results,
 * this object brings only one result.
 *
 *
 *
 * @version $Id: ManagementOperationResult.java,v 1.3 2007/01/11 19:30:40 nichele Exp $
 */
public class ManagementOperationResult {
    // -------------------------------------------------------------- Properties

    /**
     * The status code of the requested operation
     */
    private int statusCode;

    /**
     * Sets statusCode
     *
     * @param statusCode the new statusCode
     */
    public void setStatusCode(int statusCode) {
        this.statusCode = statusCode;
    }

    /**
     * Gets statusCode
     *
     * @return the current statusCode value
     */
    public int getStatusCode() {
        return statusCode;
    }

    /**
     * The the requested command. One of "Add", "Copy", "Delete", "Exec",
     * "Get", "Replace", "Sequence", "Atomic"
     */
    private String command;

    /**
     * Sets command
     *
     * @param command the new command
     */
    public void setCommand(String command) {
        this.command = command;
    }

    /**
     * Gets command
     *
     * @return the current command value
     */
    public String getCommand() {
        return command;
    }

    /**
     * The nodes property. Note that it may contain results if the
     * ManagementOperationStatus regards a Get or a set of nodes if it relates
     * to a status of any command who specified items in it.
     */
    private Map nodes;

    /**
     * Returns the nodes property
     *
     * @return the nodes property
     */
    public Map getNodes() {
        return nodes;
    }

    /**
     * Set the nodes property
     *
     * @param newNodes the new values
     */
    public void setNodes(Map newNodes) {
        this.nodes = new HashMap();
        if (newNodes == null) {
            return;
        }

        nodes.putAll(newNodes);
    }

    /**
     * Addes the given nodes to the existing nodes. If no nodes were present,
     * a new hash map is created to store them.
     *
     * @param newNodes the new values
     */
    public void addNodes(Map newNodes) {
        if (nodes == null) {
            nodes = new HashMap();
        }

        nodes.putAll(newNodes);
    }

    // ------------------------------------------------------------ Constructors

    /** Creates a new instance of ManagementOperationResult */
    public ManagementOperationResult() {
        statusCode = -1;
        command = null;
        nodes = new HashMap();
    }

    // ---------------------------------------------------------- Public methods

}
