/**
 * Copyright (C) 2003-2007 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */
package com.funambol.framework.engine.source;

import com.funambol.framework.engine.source.ContentType;

/**
 * This class wraps the following information about a <i>SyncSource</i>
 * <table>
 * <tr>
 * <td>supportedTypes</td>
 * <td>Types supported by a source</td>
 * </tr>
 * <tr>
 * <td>preferredType</td>
 * <td>The preferred source content type</td>
 * </tr>
 * </table>
 *
 *
 */
public class SyncSourceInfo implements java.io.Serializable {

    // -------------------------------------------------------------- Properties

    private ContentType[] supportedTypes = null;

    /** Getter for property supportedTypes.
     * @return Value of property supportedTypes.
     *
     */
    public ContentType[] getSupportedTypes() {
        return this.supportedTypes;
    }

    /** Setter for property supportedTypes.
     * @param supportedTypes New value of property supportedTypes.
     *
     */
    public void setSupportedTypes(ContentType[] supportedTypes) {
        this.supportedTypes = supportedTypes;
        this.preferred  = 0;
    }

    /**
     * The preferred content type index
     **/
    private int preferred = 0;

    /** Getter for property preferred.
     * @return Value of property preferred.
     *
     */
    public int getPreferred() {
        return preferred;
    }

    /** Setter for property preferredType.
     * @param preferred New value of property preferredType.
     *
     */
    public void setPreferred(int preferred) {
        this.preferred = preferred;
    }

    /**
     * Returns the preferred content type among the supported ones.
     *
     * @return the preferred content type among the supported ones.
     *
     */
    public ContentType getPreferredType() {
        assert ((supportedTypes != null) && (preferred >= 0) && (preferred < supportedTypes.length));
        return supportedTypes[preferred];
    }

    // ------------------------------------------------------------ Constructors
    /**
     * Creates a new instance of SyncSuurceInfo
     *
     * @param supportedTypes - NOT NULL or EMPTY
     * @param preferred the position in the <i>supportedTypes</i> array of the
     *                  preferred type
     *
     * @throws IllegalArgumentException if the passed in parameters are not correct
     */
    public SyncSourceInfo(ContentType[] supportedTypes, int preferred) {
        if ((supportedTypes == null) || (supportedTypes.length == 0)) {
            throw new IllegalArgumentException("supportedTypes cannot be null");
        }

        if ((preferred<0) || (preferred >= supportedTypes.length)) {
            throw new IllegalArgumentException( "preferred is "
                                              + preferred
                                              + " when the supported type are "
                                              + supportedTypes.length);
        }

        this.supportedTypes = supportedTypes;
        this.preferred = preferred;
    }

    public SyncSourceInfo() {
    }
}
