/**
 * Copyright (C) 2003-2007 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */
package com.funambol.framework.tools;

import java.security.SecureRandom;
import java.security.MessageDigest;

/**
 * This class groups utility methods for MD5 computation.
 * <p>
 *
 * NOTE: when this class is first loaded, it creates and initializes a random
 * generator that can be used to create random keys. We create and initialize
 * the generator onece, because it can be a time consuming process. Better
 * policies might be implemented in the future.
 *
 *
 */
public class MD5 {

    // ------------------------------------------------------------ Private data
    private static SecureRandom random = null;
    private static MessageDigest md    = null;

    // ------------------------------------------------------------ Constructors

    /** Creates a new instance of MD5 */
    protected MD5() {
    }

    // ---------------------------------------------------------- Public methods

    /**
     * Returns a new nonce to be used for MD5 authentication. The nonce bytes
     * are guaranteed to be in the printable range from ascii 32 to 128.
     *
     * @return a new 16 bytes long nonce
     */
    public static byte[] getNextNonce() {
        byte[] nextNonce = new byte[16];
        random.nextBytes(nextNonce);

        int i;
        for (int j=0; j<nextNonce.length; ++j) {
            i = nextNonce[j] & 0x000000ff;
            if ((i<32) || (i>128)) {
                nextNonce[j] = (byte)(32 + (i % 64));
            }
        }

        return nextNonce;
    }

    /**
     * MD5ies the given content
     *
     * @param data the data to be digested
     *
     */
    public static byte[] digest(byte[] data) {
        md.reset();
        return md.digest(data);
    }

    // --------------------------------------------------------- Private methods

    /**
     * Creates and initialize the random generator. Called ad class loading
     * time.
     */
    private static void randomGeneratorInit()
    throws java.security.NoSuchAlgorithmException {
        random = SecureRandom.getInstance("SHA1PRNG");
    }

    // ------------------------------------------------------------- Static code

    static {
        try {
            randomGeneratorInit();
            md = MessageDigest.getInstance("MD5");
        } catch(Exception e) {
            e.printStackTrace();
        }
    }
}
