/**
 * Copyright (C) 2003-2007 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */
package com.funambol.server.engine;

import com.funambol.framework.engine.SyncItem;
import com.funambol.framework.engine.SyncItemKey;
import com.funambol.framework.engine.SyncItemImpl;

import com.funambol.framework.core.Item;
import com.funambol.framework.core.ComplexData;
import com.funambol.framework.core.Target;
import com.funambol.framework.core.Source;

/**
 * Helper class to convert <i>SyncItem</i>s into <i>Item</i>s and vice versa.
 *
 * @version  $Id: SyncItemHelper.java,v 1.3 2007/01/11 19:30:50 nichele Exp $
 *
 */
public class SyncItemHelper {
    // ---------------------------------------------------------------- Costants

    public static final String PROPERTY_COMMAND = "SYNCML_COMMAND";

    // ---------------------------------------------------------- Public methods

    /**
     * Converts a generic <i>SyncItem</i> into an <i>Item</i> object.
     *
     * @param key the key the item is known by the client agent
     * @param syncItam the <i>SyncItem</i>
     * @param includeTarget <i>true</i> if the target must be included
     * @param includeSource <i>true</i> if the source must be included
     * @param includeData <i>true</i> if data must be included
     *
     * @return the <i>Item</i> object
     */
    public static Item toItem(String   key          ,
                              SyncItem syncItem     ,
                              boolean  includeTarget,
                              boolean  includeSource,
                              boolean  includeData  ) {
        ComplexData data = null;

        if (includeData) {
            data = new ComplexData(
                       new String((byte[])syncItem.getPropertyValue(SyncItem.PROPERTY_BINARY_CONTENT))
                   );
        }

        Target target = null;
        Source source = null;

        if (includeTarget) {
            target = new Target(key);
        }

        if (includeSource) {
            source = new Source(key);
        }

        return new Item(target,
                        source,
                        null  , // meta
                        data  ,
                        false); //moreData
    }

    /**
     * Create a new <i>SyncItem</i> with the content of an existing one. The
     * old SyncItem's key becomes the mappedKey of the new SyncItem.
     *
     * @param key
     * @param fromSyncItem
     */
    public static SyncItem newMappedSyncItem(SyncItemKey key, SyncItem fromSyncItem) {
        SyncItemImpl syncItem
            = new SyncItemImpl(fromSyncItem.getSyncSource()          ,
                               key.getKeyAsString()                  ,
                               fromSyncItem.getKey().getKeyAsString(),
                               fromSyncItem.getState()               );

        syncItem.setProperties(fromSyncItem.getProperties());

        return syncItem;
    }
}
