/**
 * Copyright (C) 2003-2007 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */


package com.funambol.server.engine.dm.ejb;

import java.rmi.RemoteException;

import com.funambol.framework.engine.dm.ManagementException;
import com.funambol.framework.notification.NotificationException;
import com.funambol.framework.core.dm.bootstrap.BootStrap;

/**
 * Management ejb - Remote interface
  *
 * @version $Id: ManagementRemote.java,v 1.4 2007/01/11 19:31:01 nichele Exp $
      */
public interface ManagementRemote extends javax.ejb.EJBObject {

    /**
     * Sends a notification message to the device with the given phoneNumber
     * @param messageType the type of the notification message as define in <code>NotificationConstants<code>
     * @param transportType the type of the transport as define in <code>NotificationConstants<code>
     * @param phoneNumber the phone number
     * @param operation application specific operation to be performed
     * @param info application specific detail information
     *
     * @throws NotificationException in case of errors
     */
    public void sendNotification( int messageType     ,
                                  int transportType   ,
                                  String phoneNumber  ,
                                  String operation    ,
                                  String info         )
    throws RemoteException, NotificationException, ManagementException;

    /**
     * Executes the management sequence identified by the given operation name.
     *
     * @param phoneNumber the phone number
     * @param operation the management operation name
     * @param info application specific detail information
     *
     * @throws RemoteException in case of RMI errors,
     *         ManagementException if a error occurs in the management engine,
     *         NotificationException if an error occurs in the notification process
     */
    public void executeManagementOperation( String phoneNumber  ,
                                            String operation    ,
                                            String info         )
    throws RemoteException, ManagementException, NotificationException;


    /**
     * Performs a bootstrap with the given bootstrap object
     *
     * @param bootstrap the bootstrap object with the neeed information to perfom
     *                  a bootstrap
     * @throws NotificationException if a error occurs
     */
    public void bootstrap(BootStrap bootstrap)
    throws RemoteException, ManagementException, NotificationException;


    /**
     * Performs a bootstrap with the given bootstrap objects
     *
     * @param bootstraps the bootstrap array list with the neeed information to perfom
     *                  the bootstraps
     * @throws NotificationException if a error occurs
     */
    public void bootstrap(BootStrap[] bootstraps)
    throws RemoteException, ManagementException, NotificationException;

 }
