/**
 * Copyright (C) 2003-2007 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */
package com.funambol.server.syncbean;

import javax.ejb.*;

import com.funambol.framework.server.SyncResponse;
import com.funambol.framework.server.error.ServerException;

public interface SyncLocal extends EJBLocalObject {
    /**
     * Used to process a SyncML message as translated by the client object.
     *
     * @param messageData the message as a stream of byes. NOT NULL
     * @param mimeType the mime type of the stream.
     * @param hmacHeader the hmac value associated with the request
     *
     * @throws com.funambol.framework.server.error.ServerException in case 
     *         of an error in the server that the client should be aware of.
     *
     * @return the response message
     */
    public SyncResponse processMessage(byte[] messageData,
                           String mimeType, String hmacHeader) throws ServerException;

    /**
     * Used to process a status information as needed by the client object (i.e.
     * errors or success).
     *
     * @param statusCode the status code
     * @param info additional descriptive message
     *
     * @return the response message
     *
     * @see com.funambol.framework.core.StatusCode for valid status codes.
     */
    public SyncResponse processStatusCode(int statusCode, String info);
}
