/**
 * Copyright (C) 2003-2007 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */
package com.funambol.test.tools;

import java.io.File;
import java.sql.Connection;
import java.io.IOException;
import java.sql.SQLException;
import java.sql.Statement;
import java.io.BufferedReader;
import java.io.FileReader;
import java.io.StringReader;

/**
 *
 * @version $Id: SQLTools.java,v 1.4 2007/01/11 19:31:02 nichele Exp $
 */
public class SQLTools {

    // ---------------------------------------------------------- Public Methods

    /**
     * Executes all sql queries contained in the given script file.
     * <br/>Performs a simply parser of the file ignoring line that start with '--'
     *
     * @param conn the connection to use to execute the query
     * @param file the script file
     *
     * @throws IOException
     * @throws SQLException
     */
    public static void executeScript(Connection conn, File file) throws IOException, SQLException {

        StringBuffer query = new StringBuffer();

        BufferedReader br = new BufferedReader(new FileReader(file));

        String line = null;
        StringReader lineReader = null;
        int c = 0;

        while ( (line = br.readLine()) != null ) {
            if (line.startsWith("--")) {
                // ignore comment line
                continue;
            }

            lineReader = new StringReader(line);

            while ( (c = lineReader.read()) != -1) {

                if ( (char)c == ';' ) {
                    executeQuery(conn, query.toString().trim());
                    query.delete(0, query.length());
                } else {
                    query.append( (char)c);
                }

            }

            lineReader.close();
        }

        br.close();

    }

    /**
     * Executes a query on the given connection
     *
     * @param conn the connection to use to execute the query
     * @param query the query to execute
     *
     * @throws SQLException
     * @return int
     */
    public static int executeQuery(Connection conn, String query) throws SQLException {
      Statement stmt = conn.createStatement();
      int i = stmt.executeUpdate(query);
      stmt.close();
      return i;
     }



}
